aboutsummaryrefslogtreecommitdiffstats
path: root/src/java/org/apache/fop/area/inline/UnresolvedPageNumber.java
diff options
context:
space:
mode:
authorGlen Mazza <gmazza@apache.org>2004-12-02 01:36:09 +0000
committerGlen Mazza <gmazza@apache.org>2004-12-02 01:36:09 +0000
commit67d4426da31f4c7f6344d630388c3fa7095ad6ce (patch)
treefaae66ec19654b1acab156f655fc473b9ef7f821 /src/java/org/apache/fop/area/inline/UnresolvedPageNumber.java
parentbfab061fc7b4f6f48120ffb2d04edd7e8d55644f (diff)
downloadxmlgraphics-fop-67d4426da31f4c7f6344d630388c3fa7095ad6ce.tar.gz
xmlgraphics-fop-67d4426da31f4c7f6344d630388c3fa7095ad6ce.zip
More commenting, slightly clearer method names.
git-svn-id: https://svn.apache.org/repos/asf/xmlgraphics/fop/trunk@198182 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'src/java/org/apache/fop/area/inline/UnresolvedPageNumber.java')
-rw-r--r--src/java/org/apache/fop/area/inline/UnresolvedPageNumber.java22
1 files changed, 12 insertions, 10 deletions
diff --git a/src/java/org/apache/fop/area/inline/UnresolvedPageNumber.java b/src/java/org/apache/fop/area/inline/UnresolvedPageNumber.java
index 3b56ae281..05bf28c7e 100644
--- a/src/java/org/apache/fop/area/inline/UnresolvedPageNumber.java
+++ b/src/java/org/apache/fop/area/inline/UnresolvedPageNumber.java
@@ -30,7 +30,7 @@ import java.util.List;
*/
public class UnresolvedPageNumber extends TextArea implements Resolvable {
private boolean resolved = false;
- private String pageRefId;
+ private String pageIDRef;
/**
* Create a new unresolvable page number.
@@ -38,7 +38,7 @@ public class UnresolvedPageNumber extends TextArea implements Resolvable {
* @param id the id reference for resolving this
*/
public UnresolvedPageNumber(String id) {
- pageRefId = id;
+ pageIDRef = id;
text = "?";
}
@@ -48,20 +48,22 @@ public class UnresolvedPageNumber extends TextArea implements Resolvable {
* @return the id reference for this unresolved page number
*/
public String[] getIDs() {
- return new String[] {pageRefId};
+ return new String[] {pageIDRef};
}
/**
* Resolve this page number reference.
* This resolves the reference by getting the page number
* string from the first page in the list of pages that apply
- * for the id reference. The word string is then set to the
- * page number string.
+ * for this ID. The page number text is then set to the String value
+ * of the page number.
*
- * @param id the id reference being resolved
- * @param pages the list of pages for the id reference
+ * @param id the id associated with the pages parameter
+ * @param pages the list of PageViewports associated with this ID
+ * @todo determine why the ID passed in will (always?) equal the pageIDRef,
+ * explain in comments above
*/
- public void resolve(String id, List pages) {
+ public void resolveIDRef(String id, List pages) {
resolved = true;
if (pages != null) {
PageViewport page = (PageViewport)pages.get(0);
@@ -48,20 +48,22 @@ public class UnresolvedPageNumber extends TextArea implements Resolvable {
}
/**
- * Resolve this page number reference.
- * This resolves the reference by getting the page number
+ * Resolve the page number idref
+ * This resolves the idref for this object by getting the page number
* string from the first page in the list of pages that apply